@@ -2,13 +2,35 @@
 This module defines constants commonly used in scikit-build.
 """
 
+import contextlib
 import os
 import platform
+import shutil
 import sys
+from pathlib import Path
 
 from distutils.util import get_platform
 
-CMAKE_DEFAULT_EXECUTABLE = "cmake"
+
+def _get_cmake_executable() -> str:
+    with contextlib.suppress(ImportError):
+        from cmake import CMAKE_BIN_DIR  # pylint: disable=import-outside-toplevel
+
+        path = f"{CMAKE_BIN_DIR}/cmake"
+        if Path(f"{path}.exe").is_file():
+            return f"{path}.exe"
+        return path
+
+    for name in ("cmake3", "cmake"):
+        prog = shutil.which(name)
+        if prog:
+            return prog
+
+    # Just guess otherwise
+    return "cmake"
+
+
+CMAKE_DEFAULT_EXECUTABLE = _get_cmake_executable()
 """Default path to CMake executable."""
 
 
@@ -47,7 +69,8 @@ def _default_skbuild_plat_name() -> str:
 
     # Use CMAKE_OSX_ARCHITECTURES if that is set, otherwise use ARCHFLAGS,
     # which is the variable used by Setuptools. Fall back to the machine arch
-    # if neither of those is given.
+    # if neither of those is given. Not that -D flags like CMAKE_SYSTEM_PROCESSOR
+    # will override this by setting it later.
 
     archflags = os.environ.get("ARCHFLAGS")
     if archflags is not None:
