@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """test_utils
 ------------------------
@@ -12,7 +11,6 @@ import os
 import pytest
 
 from skbuild.utils import (
-    ContextDecorator,
     PythonModuleFinder,
     mkdir_p,
     push_dir,
@@ -37,12 +35,6 @@ def teardown_module():
     os.chdir(saved_cwd)
 
 
-def test_context_decorator():
-    with ContextDecorator(foo=42) as context:
-        assert hasattr(context, "foo")
-        assert context.foo == 42
-
-
 def test_push_dir(tmpdir):
     old_cwd = os.getcwd()
     try:
